pub struct Fixed<F: FixedSigned>(/* private fields */);Expand description
Wraps a signed fixed-point number. All operations are saturating so that the underlying representation’s minimum and maximum values are able to stand in for -∞ and +∞.
Implementations
Sourceimpl<F: FixedSigned> Fixed<F>
impl<F: FixedSigned> Fixed<F>
pub const MAX: Self
pub const MIN: Self
Sourcepub fn from_num<Src: ToFixed>(src: Src) -> Self
pub fn from_num<Src: ToFixed>(src: Src) -> Self
Examples found in repository?
examples/fixed.rs (line 20)
10fn layout_paragraph<'a, P: ParagraphLayout<(), (), (), F>>(
11 paragraph: &'a str,
12 layout: &P,
13 max_width: F,
14) -> Vec<&'a str> {
15 // Process the paragraph into its items.
16 let mut items = Vec::new();
17 for c in paragraph.chars() {
18 items.push(if c.is_whitespace() && items.len() != 0 {
19 Item::Glue {
20 width: F::from_num(1),
21 stretch: F::from_num(1),
22 shrink: F::from_num(0),
23 data: (),
24 }
25 } else {
26 Item::Box {
27 width: F::from_num(1),
28 data: (),
29 }
30 });
31 }
32 items.push(Item::Glue {
33 width: F::from_num(0),
34 stretch: F::MAX,
35 shrink: F::from_num(0),
36 data: (),
37 });
38 items.push(Item::Penalty {
39 width: F::from_num(0),
40 cost: F::MIN,
41 flagged: true,
42 data: (),
43 });
44
45 // Calculate the paragraph's breaks.
46 let breaks = layout.layout_paragraph(&items, max_width);
47
48 // Render the laid-out paragraph using the break positions.
49 let mut cursor = 0;
50 let mut lines = Vec::new();
51 let mut start = 0;
52 for (i, _) in paragraph.chars().enumerate() {
53 if i == breaks[cursor].break_at {
54 lines.push(¶graph[start..i]);
55 start = i + 1;
56 cursor += 1;
57 }
58 }
59 lines.push(¶graph[start..]);
60 lines
61}
62
63fn layout_text() -> Result<String, fmt::Error> {
64 let text = " Far out in the uncharted backwaters of the unfashionable end of the western spiral arm of the Galaxy lies a small unregarded yellow sun. Orbiting this at a distance of roughly ninety-two million miles is an utterly insignificant little blue-green planet whose ape-descended life forms are so amazingly primitive that they still think digital watches are a pretty neat idea.";
65 let knuth_plass = KnuthPlass::new().with_threshold(F::MAX);
66 let lines = layout_paragraph(&text, &knuth_plass, F::from_num(80));
67 let mut result = String::new();
68 writeln!(&mut result, "┏{}┓", "━".repeat(80))?;
69 for l in lines {
70 let pad = 80 - l.chars().count();
71 writeln!(&mut result, "┃{}{}┃", l, " ".repeat(pad))?;
72 }
73 writeln!(&mut result, "┗{}┛", "━".repeat(80))?;
74 Ok(result)
75}Trait Implementations
Sourceimpl<F: FixedSigned> Add for Fixed<F>
impl<F: FixedSigned> Add for Fixed<F>
Sourceimpl<F: FixedSigned> AddAssign for Fixed<F>
impl<F: FixedSigned> AddAssign for Fixed<F>
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moreSourceimpl<F: FixedSigned> Debug for Fixed<F>
impl<F: FixedSigned> Debug for Fixed<F>
Sourceimpl<F: FixedSigned> Div for Fixed<F>
impl<F: FixedSigned> Div for Fixed<F>
Sourceimpl<F: FixedSigned> Mul for Fixed<F>
impl<F: FixedSigned> Mul for Fixed<F>
Sourceimpl<F: FixedSigned> Num for Fixed<F>
impl<F: FixedSigned> Num for Fixed<F>
Sourceimpl<F: FixedSigned> PartialEq for Fixed<F>
impl<F: FixedSigned> PartialEq for Fixed<F>
Sourceimpl<F: FixedSigned> PartialOrd for Fixed<F>
impl<F: FixedSigned> PartialOrd for Fixed<F>
Sourceimpl<F: FixedSigned> Sub for Fixed<F>
impl<F: FixedSigned> Sub for Fixed<F>
Sourceimpl<F: FixedSigned> SubAssign for Fixed<F>
impl<F: FixedSigned> SubAssign for Fixed<F>
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read moreimpl<F: Copy + FixedSigned> Copy for Fixed<F>